@@ -43,14 +43,15 @@ class InstrumentWrapper(param.Parameterized):
                 if hwid == "software":
                     name = self.modules[module]["name"]
                     self.devices[name] = {"name": name, "hwid": "software", "serial_number": "software",
-                                                        "module": module, "port": "software"}
+                                          "module": module, "port": "software"}
                 else:
                     for port in ports:
                         if debug == True:
                             print(hwid)
                             print(port.hwid.split(" ")[1].replace("VID:PID=", ""))
                         if str(hwid) == port.hwid.split(" ")[1].replace("VID:PID=", ""):
-                            if port.serial_number in self.modules[module]["serial"] or self.modules[module]["serial"] is "any":
+                            if port.serial_number in self.modules[module]["serial"] or self.modules[module][
+                                "serial"] is "any":
                                 name = f"{port.serial_number} - {port.name} - {mname} - {port.name}"
                                 self.devices[name] = {"name": port.name, "hwid": port.hwid,
                                                       "serial_number": port.serial_number, "module": module,
@@ -65,8 +66,10 @@ class InstrumentWrapper(param.Parameterized):
         initialized = True
 
     def view(self):
-
-        return pn.Column(self.param, self.button)
+        try:
+            return pn.Column(self.param, self.instrument.widgets(), self.button)
+        except:
+            return pn.Column(self.param, self.button)
 
     def serve(self):
         self.view().show(port=5006)
